package com.pablissimo.sonar;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.sonar.api.utils.command.Command;
import org.sonar.api.utils.command.CommandExecutor;
import org.sonar.api.utils.command.StreamConsumer;

public class TsLintExecutorImpl implements TsLintExecutor {
    private static final Logger LOG = LoggerFactory.getLogger(TsLintExecutorImpl.class);

    private StringBuilder stdOut;
    private StringBuilder stdErr;

    public String execute(String pathToTsLint, String configFile, String rulesDir, String file, Integer timeoutMs) {
        LOG.info("TsLint executing for " + file);
        Command command = Command.create("node");
        command.addArgument(pathToTsLint);
        command.addArgument("--format");
        command.addArgument("json");
        
        if (rulesDir != null && rulesDir.length() > 0) {
            command.addArgument("--rules-dir");
            command.addArgument(rulesDir);
        }
        
        command.addArgument("--config");
        command.addArgument(configFile);
        command.addArgument(file.trim());
        command.setNewShell(false);

        this.stdOut = new StringBuilder();
        this.stdErr = new StringBuilder();

        StreamConsumer stdOutConsumer = new StreamConsumer() {
            public void consumeLine(String line) {
                LOG.trace("TsLint Out: " + line);
                stdOut.append(line + "\n");
            }
        };

        StreamConsumer stdErrConsumer = new StreamConsumer() {
            public void consumeLine(String line) {
                LOG.error("TsLint Err: " + line);
                stdErr.append(line + "\n");
            }
        };

        this.createExecutor().execute(command, stdOutConsumer, stdErrConsumer, timeoutMs);

        return stdOut.toString();
    }
    
    protected CommandExecutor createExecutor() {
        return CommandExecutor.create();
    }
}
